pub fn skip_many<I: Input, T, E, F, R>(
i: I,
r: R,
f: F,
) -> ParseResult<I, (), E>Expand description
Applies the parser F multiple times until it fails or the maximum value of
the range has been reached, throwing away any produced value.
Propagates errors if the minimum number of iterations has not been met
Panics
Will panic if the end of the range is smaller than the start of the range.
Notes
- Will never yield more items than the upper bound of the range.